@@ -7,15 +7,15 @@ use base 'Exporter';
 our @EXPORT_OK = qw(
   COMPLETE
   EXPORT_ZIP_FILES_COUNT
-  TOTAL_ITERATION_COUNT
+  MAX_ITERATION_WAIT_TIMEOUT
   ITERATION_WAIT_TIMEOUT
   DOCUMENT_DISASSEMBLING_SUCCESS_STATUS
 );
 
 use constant COMPLETE                              => 'completed';
 use constant EXPORT_ZIP_FILES_COUNT                => 10;
-use constant TOTAL_ITERATION_COUNT                 => 10;
+use constant MAX_ITERATION_WAIT_TIMEOUT            => 300;
 use constant ITERATION_WAIT_TIMEOUT                => 1;
 use constant DOCUMENT_DISASSEMBLING_SUCCESS_STATUS => 'success';
 
-1;
+1;
\ No newline at end of file
